========
Examples
========

.. toctree::
  :maxdepth: 2


Refractive index and radius determination
-----------------------------------------

.. fancy_include:: cell_edge.py

.. fancy_include:: sphere_models.py

.. fancy_include:: imagefit_projection.py

.. fancy_include:: imagefit_rytov_sc.py
